@@ -5,8 +5,12 @@ Views for generating ical feeds.
 """
 
 from datetime import datetime
+from calendar import timegm
 
+from django.http import HttpResponse, Http404
+from django.core.exceptions import ObjectDoesNotExist
 from django.contrib.syndication.views import Feed
+from django.utils.http import http_date
 
 from django_ical import feedgenerator
 
@@ -21,7 +25,7 @@ FEED_EXTRA_FIELDS = (
     'product_id',
     'timezone',
 )
-# Extra fields added to items (events) to 
+# Extra fields added to items (events) to
 # support ical
 ICAL_EXTRA_FIELDS = (
     'timestamp',        # dtstamp
@@ -31,38 +35,63 @@ ICAL_EXTRA_FIELDS = (
     'end_datetime',     # dtend
     'transparency',     # transp
     'location',         # location
-    'geolocation'       # latitude;longitude
+    'geolocation',      # latitude;longitude
+    'organizer',        # email, cn, and role
 )
 
+
 class ICalFeed(Feed):
     """
     iCalendar Feed
 
-    Existing Django syndication feeds 
+    Existing Django syndication feeds
 
-    title => X-WR-CALNAME
-    description => X-WR-CALDESC
+    :title: X-WR-CALNAME
+    :description: X-WR-CALDESC
+    :item_guid: UID
+    :item_title: SUMMARY
+    :item_description: DESCRIPTION
+    :item_link: URL
 
-    item_guid => UID
-    item_title => SUMMARY
-    item_description => DESCRIPTION
-    item_link => URL
-     
     Extension fields
 
-    method => METHOD
-    timezone => X-WR-TIMEZONE
-
-    item_class => CLASS
-    item_timestamp => DTSTAMP
-    item_created => CREATED
-    item_modified => LAST-MODIFIED
-    item_start_datetime => DTSTART
-    item_end_datetime => DTEND
-    item_transparency => TRANSP
+    :method: METHOD
+    :timezone: X-WR-TIMEZONE
+    :item_class: CLASS
+    :item_timestamp: DTSTAMP
+    :item_created: CREATED
+    :item_modified: LAST-MODIFIED
+    :item_start_datetime: DTSTART
+    :item_end_datetime: DTEND
+    :item_transparency: TRANSP
     """
     feed_type = feedgenerator.DefaultFeed
 
+    def __call__(self, request, *args, **kwargs):
+        """
+        Copied from django.contrib.syndication.views.Feed
+
+        Supports file_name as a dynamic attr.
+        """
+        try:
+            obj = self.get_object(request, *args, **kwargs)
+        except ObjectDoesNotExist:
+            raise Http404('Feed object does not exist.')
+        feedgen = self.get_feed(obj, request)
+        response = HttpResponse(content_type=feedgen.mime_type)
+        if hasattr(self, 'item_pubdate') or hasattr(self, 'item_updateddate'):
+            # if item_pubdate or item_updateddate is defined for the feed, set
+            # header so as ConditionalGetMiddleware is able to send 304 NOT MODIFIED
+            response['Last-Modified'] = http_date(
+                timegm(feedgen.latest_post_date().utctimetuple()))
+        feedgen.write(response, 'utf-8')
+
+        filename = self._get_dynamic_attr('file_name', obj)
+        if filename:
+            response['Content-Disposition'] = 'attachment; filename="%s"' % filename
+
+        return response
+
     def _get_dynamic_attr(self, attname, obj, default=None):
         """
         Copied from django.contrib.syndication.views.Feed
@@ -80,14 +109,14 @@ class ICalFeed(Feed):
                 argcount = attr.func_code.co_argcount
             else:
                 argcount = attr.__call__.func_code.co_argcount
-            if argcount == 2: # one argument is 'self'
+            if argcount == 2:  # one argument is 'self'
                 return attr(obj)
             else:
                 return attr()
         return attr
-    
-    # Not used by icalendar but required
-    # by the Django syndication framework.
+
+    # NOTE: Not used by icalendar but required
+    #       by the Django syndication framework.
     link = ''
 
     def method(self, obj):
